summaryrefslogtreecommitdiff
path: root/lib/chef/knife.rb
diff options
context:
space:
mode:
authorTim Smith <tsmith@chef.io>2019-05-06 22:47:41 -0700
committerTim Smith <tsmith@chef.io>2019-05-07 10:37:11 -0700
commit757c42835ccea7b6b617b119f51a667dfdecf4df (patch)
tree4816d18d4ec974064cd93b9a3e564ebe32280a2b /lib/chef/knife.rb
parent3f39c7eb9a5f0eadf768cc92630744f66242dfa3 (diff)
downloadchef-757c42835ccea7b6b617b119f51a667dfdecf4df.tar.gz
Update a few more knife.rb references to include config.rb
Most of the knife.rb mentions have been updated and the docs have been updated already. Mention both since every existing user is only familiar with knfie.rb. Signed-off-by: Tim Smith <tsmith@chef.io>
Diffstat (limited to 'lib/chef/knife.rb')
-rw-r--r--lib/chef/knife.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/chef/knife.rb b/lib/chef/knife.rb
index 4cd7cdb73c..a5f56180fc 100644
--- a/lib/chef/knife.rb
+++ b/lib/chef/knife.rb
@@ -317,7 +317,7 @@ class Chef
exit 1
end
# copy Mixlib::CLI over so that it can be configured in knife.rb
# config file
Chef::Config[:verbosity] = config[:verbosity] if config[:verbosity]
end
@@ -498,7 +498,7 @@ class Chef
ui.info "Check your configuration file and ensure that your private key is readable"
when Chef::Exceptions::InvalidRedirect
ui.error "Invalid Redirect: #{e.message}"
- ui.info "Change your server location in knife.rb to the server's FQDN to avoid unwanted redirections."
+ ui.info "Change your server location in config.rb/knife.rb to the server's FQDN to avoid unwanted redirections."
else
ui.error "#{e.class.name}: #{e.message}"
end
@@ -317,7 +317,7 @@ class Chef
exit 1
end
- # copy Mixlib::CLI over so that it can be configured in knife.rb
+ # copy Mixlib::CLI over so that it can be configured in config.rb/knife.rb
# config file
Chef::Config[:verbosity] = config[:verbosity] if config[:verbosity]